@@ -35,8 +35,10 @@
 serializeJSON <- function(x, digits = 8, pretty = FALSE) {
   # just to verify that obj exists
   is(x)
+
   # we pass arguments both to asJSON as well as packaging object.
-  ans <- asJSON(pack(x), digits = digits, indent = if (isTRUE(pretty)) 0L else NA_integer_)
+  indent <- indent_init(pretty)
+  ans <- asJSON(pack(x), digits = digits, indent = indent)
   class(ans) <- "json"
   return(ans)
 }
